@@ -26,7 +26,7 @@
 #ifndef TRANSLATOR_RU_H
 #define TRANSLATOR_RU_H
 
-class TranslatorRussian : public Translator
+class TranslatorRussian : public TranslatorAdapter_1_8_15
 {
   public:
     /*! Used for identification of the language. */
@@ -68,7 +68,7 @@ class TranslatorRussian : public Translator
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Поля";
       }
@@ -83,26 +83,26 @@ class TranslatorRussian : public Translator
     { return "Подробнее..."; }
 
     /*! put in the class documentation */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trListOfAllMembers()
     {
       return "Полный список членов класса";
     }
 
     /*! used as the title of the "list of all members" page of a class */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trMemberList()
     {
       return "Cписок членов класса";
     }
 
     /*! this is the first part of a sentence that is followed by a class name */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trThisIsTheListOfAllMembers()
     { return "Полный список членов класса "; }
 
     /*! this is the remainder of the sentence after the class name */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trIncludingInheritedMembers()
     { return ", включая наследуемые из базового класса"; }
 
@@ -143,7 +143,7 @@ class TranslatorRussian : public Translator
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -160,7 +160,7 @@ class TranslatorRussian : public Translator
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Поля структур";
       }
@@ -207,7 +207,7 @@ class TranslatorRussian : public Translator
     /*! This is an introduction to the annotated compound list. */
     virtual QCString trCompoundListDescription()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных с их кратким описанием.";
       }
@@ -222,20 +222,20 @@ class TranslatorRussian : public Translator
     {
         QCString result="Список всех ";
         if(!extractAll) result+="документированных ";
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
           result+="членов структур данных со ссылками на ";
         else
           result+="членов классов со ссылками на ";
         if(!extractAll)
         {
-          if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+          if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
             result+="документацию по структуре для каждого члена.";
           else
             result+="документацию по классу для каждого члена.";
         }
         else
         {
-          if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+          if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
             result += "структуры";
           else
             result += "классы";
@@ -250,7 +250,7 @@ class TranslatorRussian : public Translator
       QCString result="Список всех ";
       if (!extractAll) result+="документированных ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="функций, переменных, макроопределений, "
                 "перечислений и определений типов";
@@ -303,7 +303,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Алфавитный указатель структур данных";
       }
@@ -330,7 +330,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -433,7 +433,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -877,7 +877,7 @@ class TranslatorRussian : public Translator
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Поля данных";
       }
@@ -1074,7 +1074,7 @@ class TranslatorRussian : public Translator
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -1149,7 +1149,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trClass(bool first_capital, bool singular)
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         QCString result((first_capital ? "Структуры данных" : "структуры данных"));
         return result;
@@ -1869,7 +1869,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trProvidedByCategory()
     {
-      return "По группам @1.";
+      return "По группам @0.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -1878,7 +1878,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trExtendsClass()
     {
-      return "Расширяет класс @1.";
+      return "Расширяет класс @0.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
